#!/usr/bin/gnuplot
#
# This file was generated from <TemplateReference 'gnuplot_header.template_fragment'>.
#

set macro

figwidth = 517
figheight = 305
dpi = 72. # This affects only the figure size and panel placement computations,
          # not the actual DPI values set in the output files
figwidth_in_inches = figwidth/dpi
figheight_in_inches = figheight/dpi

################################################################################################
# This multiplot layout code is adapted from http://www.sciencetronics.com/greenphotons/?p=570
# as an alternative to "set multiplot layout rows,cols".
# Original by Uwe Zimmermann, 2011 (CC BY-NC-SA 3.0).
mpl_top    = 0.4 #inch  outer top margin, title goes here
mpl_bot    = 0.5 #inch  outer bottom margin, x label goes here
mpl_left   = 1.0 #inch  outer left margin, y label goes here
mpl_right  = 0.02 #inch  outer right margin, y2 label goes here
mpl_dx     = 0.05 #inch  inter-plot horizontal spacing
mpl_dy     = 0.05 #inch  inter-plot vertical spacing
mpl_ny     = 2   #number of rows
mpl_nx     = 1   #number of columns

# calculate remaining free dimensions
mpl_width = ( figwidth_in_inches \
              - mpl_left - mpl_right \
              - (mpl_nx-1)*mpl_dx )/mpl_nx # width of individual plots
mpl_height = ( figheight_in_inches \
              - mpl_top - mpl_bot \
              - (mpl_ny-1)*mpl_dy )/mpl_ny # height of individual plots

# placement functions
#   rows are numbered from bottom to top
mpl_bot(n) = (mpl_bot+(n-1)*mpl_height+(n-1)*mpl_dy)/figheight_in_inches
mpl_top(n)  = 1-((mpl_top+(mpl_ny-n)*(mpl_height+mpl_dy))/figheight_in_inches)
#   columns are numbered from left to right
mpl_left(n) = (mpl_left+(n-1)*mpl_width+(n-1)*mpl_dx)/figwidth_in_inches
mpl_right(n)  = 1-((mpl_right+(mpl_nx-n)*(mpl_width+mpl_dx))/figwidth_in_inches)

mpl_set_panel(row, col) = sprintf("set lmargin at screen mpl_left(%d); \
                                   set rmargin at screen mpl_right(%d); \
                                   set tmargin at screen mpl_top(%d); \
                                   set bmargin at screen mpl_bot(%d)", \
                                   col, col, row, row)

# End of multiplot layout helper definitions.
# To set a panel, use "eval mpl_set_panel(row, column)"
################################################################################################

basefont = "phv,8"

baselinewidth = 1.

set terminal epslatex size figwidth_in_inches,figheight_in_inches color colortext standalone dashed \
    font basefont linewidth baselinewidth \
    header "\\usepackage{textcomp}\n\\newcommand{\\ft}[0]{\\footnotesize}"
set output "output.tex"

if (!exists("MP_LEFT"))   MP_LEFT = .1
if (!exists("MP_RIGHT"))  MP_RIGHT = .90
if (!exists("MP_BOTTOM")) MP_BOTTOM = .1
if (!exists("MP_TOP"))    MP_TOP = .95
if (!exists("MP_GAP"))    MP_GAP = 0.05

set multiplot layout 2,3 margins screen MP_LEFT, MP_RIGHT, MP_BOTTOM, MP_TOP spacing screen MP_GAP

set border 31 lw 5

set ytics nomirror
set xtics 400,1,550
xunits = 1000000.0
x2units = 1
yunits = 1e-21
y2units = 1e-06
zunits = 1
set yrange [8:2500]
set y2range [0.05:5]
set logscale y
set logscale y2
logformat = "$10^{\%L}$"
set format y logformat  # for 10^x format (for log scale)
set ytics add ("1" 1)   # replace 10^0 by 1
set ytics nomirror
set y2tics nomirror

set format y2 ""
set format x ""

set ylabel "NEP $(\\textrm{zW}/\\sqrt{\\textrm{Hz}})$"

set xrange [481.4:484.7]
plot \
   "tau_neg_25V.bytes" using (column(1)/xunits):(column(2)/y2units):(column(3)/y2units) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "red" \
     pointtype 6 \
   pointsize 1 \
   linewidth 2 \
   title "" \
     axes x1y2, \
        "nep_neg_25V.bytes" using (column(1)/xunits):(column(2)/yunits):(column(3)/yunits) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "black" \
     pointtype 4 \
   pointsize 1 \
   linewidth 2 \
   title "" \
     axes x1y1, \
        "nep_tef_-2V.dat" with lines title "" dt (2,2) lw 10 lc 0

unset ylabel
set format y ""
set xrange [501.2:505.5]

plot \
   "tau_0V.bytes" using (column(1)/xunits):(column(2)/y2units):(column(3)/y2units) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "red" \
     pointtype 6 \
   pointsize 1 \
   linewidth 2 \
   title "" \
     axes x1y2, \
        "nep_0V.bytes" using (column(1)/xunits):(column(2)/yunits):(column(3)/yunits) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "black" \
     pointtype 4 \
   pointsize 1 \
   linewidth 2 \
   title "" \
     axes x1y1, \
        "nep_tef_0V.dat" with lines title "" dt (2,2) lw 10 lc 0

set format y2 logformat  # for 10^x format (for log scale)
set y2tics add ("1" 1)   # replace 10^0 by 1
set y2tics add ("0.1" 0.1)
set y2tics textcolor rgb "red"
set y2label "$\\tau$ (\\textmu s)" textcolor rgb "red" offset -3

set xrange [504.2:508.5]

plot \
   "tau_pos_25V.bytes" using (column(1)/xunits):(column(2)/y2units):(column(3)/y2units) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "red" \
     pointtype 6 \
   pointsize 1 \
   linewidth 2 \
   title "" \
     axes x1y2, \
        "nep_pos_25V.bytes" using (column(1)/xunits):(column(2)/yunits):(column(3)/yunits) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "black" \
     pointtype 4 \
   pointsize 1 \
   linewidth 2 \
   title "" \
     axes x1y1, \
        "nep_tef_2V.dat" with lines title "" dt (2,2) lw 10 lc 0

unset y2label
set format y2 ""
set xrange [481.4:484.7]

set ylabel "$\\Delta\\textrm{E}$ $(\\textrm{yJ}$)" offset 1
set format x "%g"
set format y logformat
set xtics 400,1,550
xunits = 1000000.0
x2units = 1
yunits = 1e-24
y2units = 6.626e-25
zunits = 1
set yrange [6.62607004:2000]
set y2range [10:3018.4123151222457]

set label 1 "\\Large{\\fontfamily{phv}\\selectfont\\textbf{a}}" at screen 0.01,0.95
set label 2 "\\Large{\\fontfamily{phv}\\selectfont\\textbf{b}}" at screen 0.36,0.95
set label 3 "\\Large{\\fontfamily{phv}\\selectfont\\textbf{c}}" at screen 0.645,0.95

set label 4 "\\Large{\\fontfamily{phv}\\selectfont\\textbf{d}}" at screen 0.01,0.50
set label 5 "\\Large{\\fontfamily{phv}\\selectfont\\textbf{e}}" at screen 0.36,0.50
set label 6 "\\Large{\\fontfamily{phv}\\selectfont\\textbf{f}}" at screen 0.645,0.50

plot \
   "eres_J_neg_25V.bytes" using (column(1)/xunits):(column(2)/yunits):(column(3)/yunits) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "black" \
     pointtype 7 \
   title "" \
     axes x1y1, \
        "eres_GHz_neg_25V.bytes" using (column(1)/xunits):(column(2)/y2units):(column(3)/y2units) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "black" \
     pointtype 7 \
   title "" \
     axes x1y2  

unset ylabel
set format y ""
set xlabel "Probe frequency (MHz)" offset 0, 0.1
set xrange [501.2:505.5]

plot \
   "eres_J_0V.bytes" using (column(1)/xunits):(column(2)/yunits):(column(3)/yunits) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "black" \
     pointtype 7 \
   title "" \
     axes x1y1, \
        "eres_GHz_0V.bytes" using (column(1)/xunits):(column(2)/y2units):(column(3)/y2units) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "black" \
     pointtype 7 \
   title "" \
     axes x1y2  
unset xlabel

set format y2 logformat
set y2label "$\\Delta \\textrm{E}/\\textit{h}$ (GHz)" offset -1
set y2tics textcolor rgb "black"
set xrange [504.2:508.5]

plot \
   "eres_J_pos_25V.bytes" using (column(1)/xunits):(column(2)/yunits):(column(3)/yunits) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "black" \
     pointtype 7 \
   title "" \
     axes x1y1, \
        "eres_GHz_pos_25V.bytes" using (column(1)/xunits):(column(2)/y2units):(column(3)/y2units) every ::0:0 \
   binary format='%float64%float64%float64' \
   with yerrorbars         \
     linecolor rgb "black" \
     pointtype 7 \
   title "" \
     axes x1y2  


unset multiplot

# Check if the qt terminal is available.
if (strstrt(GPVAL_TERMINALS, 'qt') > 0) interactive_terminal = "qt"; \
else interactive_terminal = "wxt enhanced"

set term @interactive_terminal size figwidth,figheight  dashed
# replace "dashed" with "solid" if you want to ignore "linetype"/"lt" in plot

replot
bind Close "exit gnuplot"
